==> ckanext_toolbelt-0.2.18b0-py3-none-any.whl: ckanext/toolbelt/cli/make_config.py <==
from __future__ import annotations

import click

from . import _shared


@click.group()
def config():
    """Make config files."""


@config.command()
@_shared.option_plugin
@_shared.option_write
def pyproject(plugin: str, write: bool):
    """pyproject.toml"""
    _shared.ensure_root()
    plugin = _shared.safe_plugin_name(plugin)
    data = {
        f"{part.upper()}_CONFIG": _shared.render(
            _shared.template_source(part), {"PLUGIN": plugin}
        )
        for part in ["black", "ruff", "isort", "pytest", "pyright"]
    }
    data["PLUGIN"] = plugin

    _shared.produce(*_config_files("pyproject"), data, write)


@config.command()
@_shared.option_plugin
@_shared.option_write
def pre_commit(plugin: str, write: bool):
    """Pre-commit (https://pre-commit.com/)"""
    _shared.ensure_root()
    _shared.produce(
        *_config_files("pre-commit"),
        {"PLUGIN": _shared.safe_plugin_name(plugin)},
        write,
    )


@config.command()
@_shared.option_plugin
@_shared.option_write
def deps_makefile(plugin: str, write: bool):
    """CKAN dependency manager (https://github.com/DataShades/ckan-deps-installer)"""
    _shared.ensure_root()
    _shared.produce(
        *_config_files("deps-makefile"),
        {"PLUGIN": _shared.safe_plugin_name(plugin)},
        write,
    )


def _config_files(name: str) -> tuple[str, str]:
    if name == "pyproject":
        return f"config_{name}.toml", "pyproject.toml"

    if name == "pre-commit":
        return f"config_{name}.yaml", ".pre-commit-config.yaml"

    if name == "deps-makefile":
        return f"config_{name}.sh", "Makefile"

    click.secho(f"Unsupported config: {name}", fg="red")
    raise click.Abort()

==> ckanext_toolbelt-0.4.4-py3-none-any.whl: ckanext/toolbelt/cli/make_config.py <==
from __future__ import annotations

import click

from . import _shared


@click.group()
def config():
    """Make config files."""


@config.command()
@_shared.option_plugin
@_shared.option_write
def pyproject(plugin: str, write: bool):
    """pyproject.toml"""
    _shared.ensure_root()
    plugin = _shared.safe_plugin_name(plugin)
    data = {
        f"{part.upper()}_CONFIG": _shared.render(
            _shared.template_source(part),
            {"PLUGIN": plugin},
        )
        for part in ["black", "ruff", "isort", "pytest", "pyright", "commitizen"]
    }
    data["PLUGIN"] = plugin

    _shared.produce(*_config_files("pyproject"), data, write)


@config.command()
@_shared.option_plugin
@_shared.option_write
def pre_commit(plugin: str, write: bool):
    """Pre-commit (https://pre-commit.com/)"""
    _shared.ensure_root()
    _shared.produce(
        *_config_files("pre-commit"),
        {"PLUGIN": _shared.safe_plugin_name(plugin)},
        write,
    )


@config.command()
@_shared.option_plugin
@_shared.option_write
def deps_makefile(plugin: str, write: bool):
    """CKAN dependency manager (https://github.com/DataShades/ckan-deps-installer)"""
    _shared.ensure_root()
    _shared.produce(
        *_config_files("deps-makefile"),
        {"PLUGIN": _shared.safe_plugin_name(plugin)},
        write,
    )


@config.command()
@_shared.option_plugin
@_shared.option_write
def gulp_sass(plugin: str, write: bool):
    """Gulpfile for SCSS-based assets"""
    _shared.ensure_root()
    _shared.produce(
        *_config_files("gulp-sass"),
        {"PLUGIN": _shared.safe_plugin_name(plugin)},
        write,
    )


def _config_files(name: str) -> tuple[str, str]:
    if name == "pyproject":
        return f"config_{name}.toml", "pyproject.toml"

    if name == "pre-commit":
        return f"config_{name}.yaml", ".pre-commit-config.yaml"

    if name == "deps-makefile":
        return f"config_{name}.sh", "Makefile"

    if name == "gulp-sass":
        return f"config_{name}.js", "gulpfile.js"

    click.secho(f"Unsupported config: {name}", fg="red")
    raise click.Abort
